@@ -6,12 +6,10 @@ OC.L10N.register(
     "Copy to full name" : "Скапіяваць у поўнае імя",
     "Please select a team" : "Выберыце каманду",
     "Loading team…" : "Загрузка каманды…",
-    "Loading contacts …" : "Загрузка кантактаў …",
     "There are no contacts yet" : "Пакуль няма кантактаў.",
     "Create contact" : "Стварыць кантакт",
     "Create contacts" : "Стварыць кантакты",
     "Add contacts" : "Дадаць кантакты",
-    "Loading …" : "Загрузка …",
     "Manage team" : "Кіраванне камандай",
     "Leave team" : "Выйсці з каманды",
     "Delete team" : "Выдаліць каманду",
@@ -32,6 +30,7 @@ OC.L10N.register(
     "Add" : "Дадаць",
     "First name" : "Імя",
     "Last name" : "Прозвішча",
+    "Display name" : "Імя для паказу",
     "Save" : "Захаваць",
     "Team name" : "Назва каманды",
     "Edit" : "Рэдагаваць",
@@ -48,13 +47,15 @@ OC.L10N.register(
     "New team name" : "Назва новай каманды",
     "Promote as sole owner" : "Прызначыць як адзінага ўладальніка",
     "Promote to {level}" : "Павысіць да {level}",
+    "Demote to {level}" : "Панізіць да {level}",
     "Remove member" : "Выдаліць удзельніка",
-    "Add to {circle}" : "Дадаць у {circle}",
+    "Add to {team}" : "Дадаць у {team}",
     "Pending" : "У чаканні",
     "Add contact in group" : "Дадаць кантакт у групу",
     "Member" : "Удзельнік",
     "Add member" : "Дадаць удзельніка",
     "Close" : "Закрыць",
+    "Could not leave the team {displayName}" : "Не ўдалося выйсці з каманды {displayName}",
     "User" : "Карыстальнік",
     "Group" : "Група",
     "Email" : "Электронная пошта",
@@ -69,6 +70,9 @@ OC.L10N.register(
     "Address" : "Адрас",
     "Birthday" : "Дзень нараджэння",
     "Place of birth" : "Месца нараджэння",
-    "Unknown" : "Невядомы"
+    "Unknown" : "Невядомы",
+    "Loading contacts …" : "Загрузка кантактаў …",
+    "Loading …" : "Загрузка …",
+    "Add to {circle}" : "Дадаць у {circle}"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
