@@ -4,7 +4,6 @@ OC.L10N.register(
     "Details" : "Munudoù",
     "Contacts" : "Darempredoù",
     "Add contacts" : "Ouzhpennañ darempredoù",
-    "Loading …" : "O Kargañ ...",
     "General settings" : "Stummoù hollek",
     "Rename" : "Adenvel",
     "Send email" : "Kas postel",
@@ -23,7 +22,6 @@ OC.L10N.register(
     "Title" : "Titl",
     "Company" : "Embregerez",
     "View profile" : "Gwelet ar profil",
-    "Search contacts …" : "Klask darempred ...",
     "Search for people to add" : "Klask tud da ouzhpennañ",
     "No results" : "Disoc'h ebet",
     "Pending" : "O c'hortoz",
@@ -49,6 +47,8 @@ OC.L10N.register(
     "Birthday" : "Deiz-ha-bloaz",
     "Brother" : "Breur",
     "Sister" : "C'hoar",
-    "Unknown" : "Dianv"
+    "Unknown" : "Dianv",
+    "Loading …" : "O Kargañ ...",
+    "Search contacts …" : "Klask darempred ..."
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
