@@ -13,13 +13,11 @@ OC.L10N.register(
     "There was an error fetching the member list" : "メンバーリストの取得中にエラーが発生しました",
     "Please select a team" : "チームを選択してください",
     "Loading team…" : "チームを読み込み中...",
-    "Loading contacts …" : "連絡先を読み込み中...",
     "There are no contacts yet" : "連絡先はまだありません",
     "Create contact" : "連絡先を作成",
     "There are no contacts in this group" : "このグループには連絡先がありません",
     "Create contacts" : "連絡先を作成",
     "Add contacts" : "連絡先を追加",
-    "Loading …" : "読み込み中…",
     "Manage team" : "チームを管理",
     "Leave team" : "チームを離脱",
     "Delete team" : "チームを削除",
@@ -91,7 +89,6 @@ OC.L10N.register(
     "An error happened during the config change" : "構成の変更中にエラーが発生しました",
     "Enforce password protection on files shared to this team" : "このチームと共有するファイルにパスワード保護を強制します",
     "Use a unique password for all shares to this team" : "このチームのすべての共有に一意のパスワードを使用します",
-    "Unique password …" : "固有パスワード...",
     "Save" : "保存",
     "Change unique password" : "固有パスワードを変更",
     "Failed to save password. Please try again later." : "パスワードを保存できませんでした。後でもう一度やり直してください",
@@ -152,7 +149,6 @@ OC.L10N.register(
     "Deck cards with you" : "デッキカード",
     "No shared items with this contact" : "この連絡先との共有アイテムはありません",
     "Groups" : "グループ",
-    "Search contacts …" : "連絡先を検索...",
     "Add to {group}" : "{group}に追加",
     "Add members to {group}" : "ユーザーを{group}に追加",
     "Remove {type}" : "{type} を削除",
@@ -181,13 +177,9 @@ OC.L10N.register(
     "Unable to get the results" : "結果を取得できません",
     "Some members could not be added" : "一部のメンバーを追加できませんでした",
     "There was an issue adding members to the team" : "チームへのメンバーの追加で問題が発生しました",
-    "Loading members list …" : "メンバーリストを読み込んでいます…",
     "The list of members is only visible to members of this team" : "メンバーのリストは、このチームのメンバーにのみ表示されます",
     "You currently have no access to the member list" : "メンバーリストへのアクセス権がありません",
-    "Add to {circle}" : "{circle} に追加",
-    "Invite members to {circle}" : "メンバーに{circle} に参加するように招待します",
     "Pending" : "保留中",
-    "Select chart …" : "組織図を選択...",
     "Chart" : "チャート",
     "Select Date" : "日付を選択",
     "Select type" : "タイプを選択",
@@ -313,6 +305,13 @@ OC.L10N.register(
     "An error has occurred in team(s). Check the console for more details." : "チームでエラーが発生しました。詳細については、コンソールを確認してください。",
     "Unable to create team {circleName}" : "チーム{circleName}を作成できません",
     "Unable to delete team {circleId}" : "チーム {circleId} を削除できません",
-    "Unable to delete contact" : "連絡先を削除できません。"
+    "Unable to delete contact" : "連絡先を削除できません。",
+    "Loading contacts …" : "連絡先を読み込み中...",
+    "Loading …" : "読み込み中…",
+    "Unique password …" : "固有パスワード...",
+    "Search contacts …" : "連絡先を検索...",
+    "Loading members list …" : "メンバーリストを読み込んでいます…",
+    "Add to {circle}" : "{circle} に追加",
+    "Select chart …" : "組織図を選択..."
 },
 "nplurals=1; plural=0;");
