@@ -11,13 +11,11 @@ OC.L10N.register(
     "Omit year" : "연도 생략",
     "Allow updating avatars from social media" : "소셜 네트워크에서 아바타 업데이트를 허용",
     "There was an error fetching the member list" : "회원 목록을 불러오는 중 오류 발생",
-    "Loading contacts …" : "연락처 불러오는 중…",
     "There are no contacts yet" : "연락처 없음",
     "Create contact" : "연락처 생성",
     "There are no contacts in this group" : "이 그룹에 포함된 연락처 없음",
     "Create contacts" : "연락처 만들기",
     "Add contacts" : "연락처 추가",
-    "Loading …" : "불러오는 중 …",
     "Contacts settings" : "연락처 설정",
     "General settings" : "일반 설정",
     "Update avatars from social media" : "소셜 네트워크에서 아바타 업데이트",
@@ -69,7 +67,6 @@ OC.L10N.register(
     "Last modified" : "수정한 날짜",
     "Sort by {sorting}" : "{sorting}(으)로 정렬",
     "An error happened during the config change" : "변경 사항을 설정하는 중 오류 발생",
-    "Unique password …" : "독자 암호 ...",
     "Save" : "저장",
     "Change unique password" : "독자 암호 변경",
     "Failed to save password. Please try again later." : "암호를 저장하는 데 실패했습니다. 잠시 후 다시 시도하십시오.",
@@ -77,6 +74,7 @@ OC.L10N.register(
     "Cancel" : "취소",
     "Request to join" : "등록 요청",
     "You are not a member of {circle}" : "당신은 {circle}의 회원이 아닙니다.",
+    "Confirm" : "확정",
     "Add more info" : "정보 추가",
     "More fields" : "더 많은 입력란",
     "Please select a valid format" : "유효한 형식을 선택하십시오",
@@ -121,7 +119,6 @@ OC.L10N.register(
     "Talk conversations with you" : "나와의 Talk 대화",
     "Calendar events with you" : "나와의 달력 일정",
     "No shared items with this contact" : "이 연락처와 공유된 항목 없음",
-    "Search contacts …" : "연락처 검색…",
     "Add to {group}" : "{group}에 추가",
     "Remove {type}" : "{type} 삭제",
     "Add to group" : "그룹에 추가",
@@ -141,11 +138,8 @@ OC.L10N.register(
     "Remove member" : "회원 삭제",
     "Unable to get the results" : "결과를 받아올 수 없음",
     "Some members could not be added" : "일부 회원을 추가할 수 없음",
-    "Loading members list …" : "회원 목록 불러오는 중 ...",
     "You currently have no access to the member list" : "현재 이 구성원 목록에 접근할 수 없습니다",
-    "Add to {circle}" : "{circle}에 추가",
     "Pending" : "보류 중",
-    "Select chart …" : "차트 선택 ...",
     "Chart" : "차트",
     "Select Date" : "날짜 선택",
     "Select type" : "종류 선택",
@@ -245,6 +239,13 @@ OC.L10N.register(
     "Time zone" : "시간대",
     "Spoken languages" : "사용 언어",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["연락처 {failed}개를 읽을 수 없음"],
-    "Unable to delete contact" : "연락처를 삭제할 수 없음"
+    "Unable to delete contact" : "연락처를 삭제할 수 없음",
+    "Loading contacts …" : "연락처 불러오는 중…",
+    "Loading …" : "불러오는 중 …",
+    "Unique password …" : "독자 암호 ...",
+    "Search contacts …" : "연락처 검색…",
+    "Loading members list …" : "회원 목록 불러오는 중 ...",
+    "Add to {circle}" : "{circle}에 추가",
+    "Select chart …" : "차트 선택 ..."
 },
 "nplurals=1; plural=0;");
