@@ -13,13 +13,11 @@ OC.L10N.register(
     "There was an error fetching the member list" : "获取成员列表时发生一个错误",
     "Please select a team" : "请选择团队",
     "Loading team…" : "正在加载团队…",
-    "Loading contacts …" : "正在加载联系人 ...",
     "There are no contacts yet" : "尚无联系人",
     "Create contact" : "创建联系人",
     "There are no contacts in this group" : "此群组中没有联系人",
     "Create contacts" : "新建联系人",
     "Add contacts" : "添加联系人",
-    "Loading …" : "正在加载…",
     "Manage team" : "管理团队",
     "Leave team" : "离开团队",
     "Delete team" : "删除团队",
@@ -91,7 +89,6 @@ OC.L10N.register(
     "An error happened during the config change" : "更改配置时发生一个错误",
     "Enforce password protection on files shared to this team" : "对与此团队共享的文件强制实施密码保护",
     "Use a unique password for all shares to this team" : "为此团队的全部共享使用唯一密码",
-    "Unique password …" : "独立密码 ...",
     "Save" : "保存",
     "Change unique password" : "修改独立密码",
     "Failed to save password. Please try again later." : "保存密码失败，请稍后重试。",
@@ -163,12 +160,13 @@ OC.L10N.register(
     "Please select at least one editable contact to delete" : "请至少选择一个可编辑的联系人进行删除",
     "Please select two editable contacts to merge" : "请选择两个可编辑的联系人进行合并",
     "Are you sure you want to proceed?" : "是否确定要继续？",
-    "Search contacts …" : "搜索联系人 ...",
     "Unselect {number}" : "取消选择 {number}",
     "Add to {group}" : "添加到 {group}",
+    "Add members to {group}" : "将成员添加到 {group}",
     "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "请注意，您只能将可写通讯录中的联系人添加到联系人组。无法添加只读通讯录（如系统通讯录）中的联系人。",
     "Remove {type}" : "移除 {type}",
     "Add to group" : "添加到群组",
+    "Add members to group" : "将成员添加到组",
     "Search {types}" : "搜索 {types}",
     "Add guest" : "添加访客",
     "Search for people to add" : "搜索要添加的人",
@@ -195,12 +193,11 @@ OC.L10N.register(
     "Unable to get the results" : "无法获得结果",
     "Some members could not be added" : "无法添加一些成员",
     "There was an issue adding members to the team" : "向团队添加成员时出现问题",
-    "Loading members list …" : "正在加载成员列表 ...",
     "The list of members is only visible to members of this team" : "成员列表仅对此团队的成员可见",
     "You currently have no access to the member list" : "您目前无法访问成员列表",
-    "Add to {circle}" : "添加到 {circle}",
+    "Add to {team}" : "添加到 {team}",
+    "Invite members to {team}" : "邀请成员加入 {team}",
     "Pending" : "待定",
-    "Select chart …" : "选择图表 ...",
     "Chart" : "图表",
     "Select Date" : "选择日期",
     "Select type" : "选择类型",
@@ -327,9 +324,16 @@ OC.L10N.register(
     "Spoken languages" : "口语",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 个联系人读取失败"],
     "An error has occurred in team(s). Check the console for more details." : "团队中出现错误。有关更多详情，请查看控制台。",
-    "Unable to create team {circleName}" : "无法创建团队 {圈子名称}",
+    "Unable to create team {circleName}" : "无法创建团队 {circleName}",
     "Unable to delete team {circleId}" : "无法删除团队 {circleId}",
     "Unable to delete contact" : "无法删除联系人",
-    "Invite members to team" : "邀请成员加入团队"
+    "Loading contacts …" : "正在加载联系人 ...",
+    "Loading …" : "正在加载…",
+    "Unique password …" : "独立密码 ...",
+    "Search contacts …" : "搜索联系人 ...",
+    "Invite members to team" : "邀请成员加入团队",
+    "Loading members list …" : "正在加载成员列表 ...",
+    "Add to {circle}" : "添加到 {circle}",
+    "Select chart …" : "选择图表 ..."
 },
 "nplurals=1; plural=0;");
