@@ -13,13 +13,11 @@ OC.L10N.register(
     "There was an error fetching the member list" : "擷取成員清單時發生錯誤",
     "Please select a team" : "請選取團隊",
     "Loading team…" : "正在載入團隊……",
-    "Loading contacts …" : "正在載入聯絡人……",
     "There are no contacts yet" : "目前沒有連絡人",
     "Create contact" : "建立聯絡人",
     "There are no contacts in this group" : "群組中沒有連絡人",
     "Create contacts" : "建立聯絡人",
     "Add contacts" : "新增聯絡人",
-    "Loading …" : "正在載入……",
     "Manage team" : "管理團隊",
     "Leave team" : "離開團隊",
     "Delete team" : "刪除團隊",
@@ -91,7 +89,6 @@ OC.L10N.register(
     "An error happened during the config change" : "變更設定時發生錯誤",
     "Enforce password protection on files shared to this team" : "對分享到此團隊的檔案加上密碼保護",
     "Use a unique password for all shares to this team" : "對此團隊的所有分享使用獨一無二的密碼",
-    "Unique password …" : "獨一無二的密碼……",
     "Save" : "儲存",
     "Change unique password" : "變更獨一無二的密碼",
     "Failed to save password. Please try again later." : "儲存密碼失敗。請稍後再試。",
@@ -163,7 +160,6 @@ OC.L10N.register(
     "Please select at least one editable contact to delete" : "請選取至少一個可編輯的聯絡人來刪除",
     "Please select two editable contacts to merge" : "請選取兩個可編輯的聯絡人進行合併",
     "Are you sure you want to proceed?" : "您想要繼續嗎？",
-    "Search contacts …" : "搜尋聯絡人……",
     "Unselect {number}" : "取消選取 {number}",
     "Add to {group}" : "新增至 {group}",
     "Add members to {group}" : "新增成員至 {group}",
@@ -197,13 +193,11 @@ OC.L10N.register(
     "Unable to get the results" : "無法取得結果",
     "Some members could not be added" : "無法新增部份成員",
     "There was an issue adding members to the team" : "將成員新增至團隊時發生錯誤",
-    "Loading members list …" : "正在載入成員清單……",
     "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
     "You currently have no access to the member list" : "您目前無權存取成員清單",
-    "Add to {circle}" : "新增至 {circle}",
-    "Invite members to {circle}" : "邀請成員至 {circle}",
+    "Add to {team}" : "新增至 {team}",
+    "Invite members to {team}" : "邀請成員至 {team}",
     "Pending" : "擱置中",
-    "Select chart …" : "選取圖表……",
     "Chart" : "圖表",
     "Select Date" : "選取日期",
     "Select type" : "選取類型",
@@ -333,6 +327,13 @@ OC.L10N.register(
     "Unable to create team {circleName}" : "無法建立團隊 {circleName}",
     "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
     "Unable to delete contact" : "無法刪除聯絡人",
-    "Invite members to team" : "邀請成員加入團隊"
+    "Loading contacts …" : "正在載入聯絡人……",
+    "Loading …" : "正在載入……",
+    "Unique password …" : "獨一無二的密碼……",
+    "Search contacts …" : "搜尋聯絡人……",
+    "Invite members to team" : "邀請成員加入團隊",
+    "Loading members list …" : "正在載入成員清單……",
+    "Add to {circle}" : "新增至 {circle}",
+    "Select chart …" : "選取圖表……"
 },
 "nplurals=1; plural=0;");
